The brightest-path-tracing Python package was developed by [Vasudha Jha](https://github.com/VasudhaJha) as a Computer Science Masters project in collaboration with [Robert Cudmore](https://github.com/cudmore) in the [Cudmore lab](https://cudmorelab.github.io/) at the University of California at Davis.

Please get in touch if you would like to use any of our tools.